@@ -7,6 +7,9 @@
 #'
 #' @return returns the string with html code
 #'
+#' @importFrom htmltools tags
+#' @importFrom glue glue
+#'
 #' @author George Moroz <agricolamz@gmail.com>
 #' @examples
 #'
@@ -21,21 +24,16 @@ insert_images <- function(src,
                           alt = "image",
                           image_width="100%",
                           image_height="100%"){
-  df <- data.frame(src, alt,
+  df <- data.frame(src,
+                   alt,
                    image_width,
                    image_height,
                    stringsAsFactors = FALSE)
-  l <- lapply(seq_along(src), function(i){
-    paste0(c('<img src="',
-             df$src[i],
-             '" alt = "',
-             df$alt[i],
-             '" width = "',
-             df$image_width[i],
-             '" height = "',
-             df$image_height[i],
-             '">'),
-           collapse = "")
+
+  lapply(seq_along(src), function(i){
+    htmltools::img(src = df$src[i],
+                   alt = df$alt[i],
+                   width = df$image_width[i],
+                   height = df$image_height[i])
   })
-  unlist(l)
 }
